@@ -32,7 +32,16 @@ POST_REQUEST_PASSWORD_FIELD = XAUTH.get('POST_REQUEST_PASSWORD_FIELD', 'password
 EMAIL_TEMPLATES_DIRECTORY = XAUTH.get('EMAIL_TEMPLATES_DIRECTORY', 'xauth/mails/')
 EMAIL_TEMPLATE_SUFFIX = XAUTH.get('EMAIL_TEMPLATE_SUFFIX', 'html')
 PASSWORD_LENGTH = 128
-_SERIALIZERS = XAUTH.get('SERIALIZER_CLASSES', {})
+_SERIALIZERS = XAUTH.get('SERIALIZER_CLASSES', {
+    'PROFILE': {
+        'REQUEST': None,
+        'RESPONSE': None,
+    },
+    'SIGNUP': {
+        'REQUEST': None,
+        'RESPONSE': None,
+    },
+})
 _PROFILE_SERIALIZERS = XAUTH.get('PROFILE', {})
 PROFILE_REQUEST_SERIALIZER = _PROFILE_SERIALIZERS.get('REQUEST', None)
 PROFILE_RESPONSE_SERIALIZER = _PROFILE_SERIALIZERS.get('RESPONSE', None)
